/*
 * This file is part of the xTuple ERP: PostBooks Edition, a free and
 * open source Enterprise Resource Planning software suite,
 * Copyright (c) 1999-2014 by OpenMFG LLC, d/b/a xTuple.
 * It is licensed to you under the Common Public Attribution License
 * version 1.0, the full text of which (including xTuple-specific Exhibits)
 * is available at www.xtuple.com/CPAL.  By using this software, you agree
 * to be bound by its terms.
 */

#ifndef CHECK_H
#define CHECK_H

#include "guiclient.h"
#include "xwidget.h"

#include "ui_check.h"

class ParameterList;

class check : public XWidget, public Ui::check
{
    Q_OBJECT

  public:
    check(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
    ~check();

    enum SetResponse set(const ParameterList &);

  public slots:
    virtual void clear();
    virtual void sFillList();
    virtual void sPopulate();

  protected slots:
    virtual void languageChange();

  private:
    int _checkid;

};

#endif // CHECK_H
